import React, {Component} from "react";
import {Button, Col} from 'react-bootstrap'
import '../Style.css'
import SaisieAbs from "./Absences/SaisieAbs";
import SupprAbs from "./Absences/SupprAbs";
import JustAbs from "./Absences/JustAbs";

class Absences extends Component {
    constructor(props){
        super(props)
        this.state = {
            // Gestion des fenetres modales
            // Ajout d'absences
            isOpen: false,
            // Suppression
            isDelOpen: false,
            // Justification
            isJustOpen: false,
            // Données de la liste des absences
            abs: [],
            absjust: [],
            // Données d'une absence selectionnée
            data: {}
        }
    }

    // Recuperation des données en cas de changement de props (dans notre cas, changement d'élève)
    componentDidUpdate(prevProps) {
        if (prevProps.id !== this.props.id) {
            this.getData();
        }
    }

    // Recuperation des données lors du chargement de la page si un étudiant est selectionné
    componentDidMount() {
        if (this.props.id !== "") {this.getData()}
    }

    openModal(key, data) {
        this.setState({[key]: true}, () => setTimeout(() => {
            this.setState({[key]: false})
        }, 500))
        if (data) {this.setState({data: data})}
    }

    getData() {
        this.getAbs()
        this.getAbsJust()
    }

    getAbs() {
        let dept = window.location.href.split('/')[6]
        let BASE_URL = window.$api_url
        if (this.state.id !== "") {
            fetch(BASE_URL + dept + "/Scolarite/Absences/ListeAbsEtud?format=json&absjust_only=0&etudid=" + this.props.id, {
                method: 'GET',
                verify: false,
                credentials: 'include',
            })
                .then(response =>
                    // Traitement des données JSON
                    response.json().then(data => ({
                            data: data,
                        })
                    ).then(res => {
                        // Recuperation de la liste des absences
                        this.setState({abs: res.data})
                    })
                );
        }
    }

    getAbsJust() {
        let dept = window.location.href.split('/')[6]
        let BASE_URL = window.$api_url
        if (this.state.id !== "") {
            fetch(BASE_URL + dept + "/Scolarite/Absences/ListeAbsEtud?format=json&absjust_only=1&etudid=" + this.props.id, {
                method: 'GET',
                verify: false,
                credentials: 'include',
            })
                .then(response =>
                    // Traitement des données JSON
                    response.json().then(data => ({
                            data: data,
                        })
                    ).then(res => {
                        // Recuperation de la liste des absences
                        this.setState({absjust: res.data})
                    })
                );
        }
    }

    render() {
        return (
            <div className="wrapper">
                {this.props.id !== "" &&
                    // Gestion du modal de saisie
                    <SaisieAbs open={this.state.isOpen} etudid={this.props.id}/>
                } {this.props.id !== "" &&
                    // Gestion du modal de suppression
                    <SupprAbs open={this.state.isDelOpen} etudid={this.props.id} data={this.state.data}/>
                } {this.props.id !== "" &&
                    // Gestion du modal de justification
                    <JustAbs open={this.state.isJustOpen} etudid={this.props.id} data={this.state.data}/>
                }
                <h1 id="pageTitle">Gestion des absences</h1>
                {this.props.name !== "" &&
                <div className="col-sm" id="wrapDept">
                    <h4>Absences de {this.props.name + " "}
                        <Button variant="primary" size="sm" style={{"margin-right": "2px"}}
                                onClick={() => this.openModal('isOpen', null)}>
                            <span>+</span>
                        </Button>
                        <Button variant="secondary" size="sm" style={{"margin-left": "2px"}}
                                onClick={() => this.getData()}>
                            <span>🗘</span>
                        </Button>
                    </h4>
                    {(this.state.abs.length === 0 && this.state.absjust.length === 0 && this.props.name !== "") &&
                        <h6>Aucune absence de l'élève</h6>
                    }
                    {this.state.abs.map((abs, index) => {
                        return (
                            <div className="col-sm" id="wrapDept">
                                <Col>
                                    <h5>{abs.datedmy} | {abs.matin}</h5>
                                    {abs.motif !== "" &&
                                    <span>Motif: {abs.motif}</span>
                                    } {abs.exams !== "" &&
                                <span>Exam a rattraper: {abs.exams}</span>
                                }
                                </Col>
                                <Col>
                                    {abs.motif === "" &&
                                    <Button variant="primary" size="sm" style={{"margin-right": "2px"}}
                                            onClick={() => this.openModal('isJustOpen', {
                                                date: abs.datedmy,
                                                demijournee: abs.ampm
                                            })}>
                                        Justifier
                                    </Button>
                                    }
                                    <Button variant="danger" size="sm" style={{"margin-left": "2px"}}
                                            onClick={() => this.openModal('isDelOpen', {
                                                date: abs.datedmy,
                                                demijournee: abs.ampm
                                            })}>
                                        Supprimer
                                    </Button>
                                </Col>
                            </div>
                        )
                    })}
                    {this.state.absjust.map((abs, index) => {
                        return (
                            <div className="col-sm" id="wrapDept">
                                <Col>
                                    <h5>{abs.datedmy} | {abs.matin}</h5>
                                    {abs.motif !== "" &&
                                    <span>Motif: {abs.motif}</span>
                                    } {abs.exams !== "" &&
                                <span>Exam a rattraper: {abs.exams}</span>
                                }
                                </Col>
                                <Col>
                                    <Button variant="danger" size="sm" style={{"margin-left": "2px"}}
                                            onClick={() => this.openModal('isDelOpen', {
                                                date: abs.datedmy,
                                                demijournee: abs.ampm
                                            })}>
                                        Supprimer
                                    </Button>
                                </Col>
                            </div>
                        )
                    })}
                </div>
                }
            </div>
        )
    }
}

export default Absences